@@ -486,11 +486,10 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
     if ("default" %in% types) mydata$default <- 0 ## FIX ME
     
    
-    mydata <- group_by_(mydata, .dots = types) %>%
-      do(timeAverage(., avg.time = avg.time,
+    mydata <- timeAverage(mydata, type = types, avg.time = avg.time,
                      statistic = statistic, percentile = percentile,
-                     data.thresh = data.thresh))
-    
+                     data.thresh = data.thresh)
+  
   }
   
   ## the following makes sure all variables are present, which depends on 'group'
@@ -539,7 +538,7 @@ scatterPlot <- function(mydata, x = "nox", y = "no2", z = NA, method = "scatter"
     vars <- unique(c(vars, "wd", "ws"))
   
   if (!is.na(z)) vars <- c(vars, z)
-  mydata <- checkPrep(mydata, vars, type)
+  mydata <- checkPrep(mydata, unique(vars), type)
   
   ## remove missing data except for time series where we want to show gaps
   ## this also removes missing factors
