@@ -370,7 +370,7 @@ timePlot <- function(mydata, pollutant = "nox", group = FALSE, stack = FALSE,
 
     theStrip <- strip
 
-    if (date.pad) mydata <- date.pad(mydata)
+    if (date.pad) mydata <- date.pad(mydata, type = type)
 
     mydata <- cutData(mydata, type, ...)
 
@@ -391,13 +391,17 @@ timePlot <- function(mydata, pollutant = "nox", group = FALSE, stack = FALSE,
 
         } else {
             
-            mydata <- group_by_(mydata, type) %>%
-              do(timeAverage(., pollutant = pollutant, avg.time = avg.time, 
+            mydata <- timeAverage(mydata, pollutant = pollutant, 
+                                  type = type, statistic = statistic,
+                                  avg.time = avg.time, 
                                 data.thresh = data.thresh,
-                                percentile = percentile))
+                                percentile = percentile)
         }
     }
     
+    # timeAverage drops type if default
+    if (type == "default") mydata$default <- "default"
+    
     if (!is.null(windflow)) {
         
          mydata <- melt(mydata, id.var = c("date", type, "ws", "wd"))
